# tts-clients

Various TTS clients for Python.

## Installation

```bash
pip install tts-clients
```

## Available Clients

- [MiniMax T2A](https://www.minimax.io/platform_overview)
- [Google TTS](https://ai.google.dev/gemini-api/docs/speech-generation)
- [OpenAI TTS](https://platform.openai.com/docs/guides/text-to-speech)
- [ElevenLabs TTS](https://elevenlabs.io/docs/quickstart)
